<?php
/**
 * Created by IntelliJ IDEA.
 * User: goldie
 * Date: 21/07/2016
 * Time: 11:01
 */

namespace BrewPixel\Barista\Percolator;

/**
 * Class Sanitise
 *
 * @package barista\Percolator
 */
class Sanitise {

	/**
	 * Make string lowercase. Wrapper for PHP function.
	 *
	 * @param string $string The string to transform.
	 *
	 * @return string
	 */
	public function to_lowercase( $string ) {
		$lowercase = strtolower( $string );

		return $lowercase;
	}

	/**
	 * Make string lowercase. Wrapper for PHP function.
	 *
	 * @param string $string The string to transform.
	 *
	 * @return string
	 */
	public function remove_spaces( $string ) {
		$spaces_removed = str_replace( ' ', '', $string );

		return $spaces_removed;
	}

	/**
	 * Make string lowercase. Wrapper for PHP function.
	 *
	 * @param string $string The string to transform.
	 *
	 * @return string
	 */
	public function replace_spaces( $string, $replacement ) {
		$spaces_replaced = str_replace( ' ', "$replacement", $string );

		return $spaces_replaced;
	}

	/**
	 * Remove disallowed protocols from URL.
	 *
	 * @param string $url The URL to transform.
	 * @param array  $disallowed_protocols List of disallowed protocols.
	 *
	 * @return mixed
	 */
	public function remove_disallowed_url_protocols( $url, array $disallowed_protocols = array( 'http', 'https', 'ftp', 'mailto', 'file', 'data' ) ) {
		foreach ( $disallowed_protocols as $protocol ) {
			$protocol .= '://';
			if ( strpos( $url, $protocol ) === 0 ) {
				return str_replace( $protocol, '', $url );
			}
		}
		return $url;
	}

	/**
	 * Remove disallowed characters from string.
	 *
	 * @param string $string The string to transform.
	 * @param array  $disallowed_characters List of disallowed characters.
	 *
	 * @return string
	 */
	public function remove_disallowed_characters( $string, array $disallowed_characters = array() ): string {
		foreach ( $disallowed_characters as $characters ) {
			if ( strpos( $string, $characters ) === 0 ) {
				return str_replace( $characters, '', $string );
			}
		}
		return $string;
	}

	/**
	 * Limit string length.
	 *
	 * @param string $string String.
	 * @param int    $length Length.
	 *
	 * @return false|string
	 */
	public function limit_string_length( $string, $length ) {
		$string = substr( $string, 0, $length );

		return $string;
	}

	/**
	 * @param $string
	 * @param $pattern
	 * @param $replacement
	 *
	 * @return string|string[]|null
	 */
	public function sanitise_with_preg_replace( $string, $pattern, $replacement ) {
		return preg_replace( $pattern, $replacement, $string );
	}
}
